import { setStorageAsync, removeStorage } from '@/lib/storage'
// import store from '@/store/index.js'
import { login, logout } from '@/apis/user.js'
import Toast from '@/lib/toast/index.js'
const state = {
	token: null,
	openid: null,
	unionid: null,
	session_key: '',
	userInfo: {},
	location: {},
	
	isOverdue: false, // 服务是否过期
	
	isLogin: true,

}

const mutations = {
	SETTOKEN(state, token){
		state.token = token
	},
	SETLOGINSTATUS(state, status) {
		state.isLogin = status
	},
	SETUSERINFO(state, userInfo){
		state.userInfo = userInfo
	},
	LOGIN(state, params) {
		state.token = params.token
		state.userInfo.user = params.user
	},
	LOGOUT(state){
		state.token = ''
		state.userInfo = {}
	}
}

const actions = {
	setToken: ({commit}, token) => {
		commit('SETTOKEN', token)
		setStorageAsync('token',token)
	},
	setLoginStatus: ({commit}, status) => {
		commit('SETLOGINSTATUS', status)
	},
	setLocation: async ({state}) => {
		uni.getLocation({
			type: 'gcj02',
			success: res => {
				state.location.longitude =  res.longitude || null
				state.location.latitude = res.latitude || null
			}
		})
	},
	setUserInfo: ({commit}, userInfo) => {
		commit('SETUSERINFO', userInfo)
		setStorage('userInfo',userInfo)
	},
	login: async ({commit}, form) => {
		try{
			const { status, data } = await login(form)
			if(status) {
				setStorageAsync('token', data.token)
				commit('LOGIN', data)
				uni.navigateBack()
			}
			
		}catch(e){
			Toast({title: e.msg || '登录失败'})
		}
	},
	logout: async ({commit})=>{
		try{
			const { status, data } = await logout()
			if(status) {
				commit('LOGOUT')
				removeStorage('token')
			}
		}catch(e){
			Toast({title: e.msg || '退出登录失败'})
		}
	}
}

export default {
    namespaced: true, 
    state,
	mutations,
	actions
}